@@ -108,8 +108,7 @@ class JinjaStaticRenderer():
                 ast = self.env.parse(self.env.loader.get_source(self.env, template))
                 self.template_trees[template] = list(meta.find_referenced_templates(ast))
             except:
-                self.template_trees[template] = False
-
+19
         return self.template_trees[template]
 
     def get_global_vars(self):
@@ -155,7 +154,6 @@ class JinjaStaticRenderer():
         new_directory = os.path.split(new_file_path)[0]
         
 
-
         # Force a render if the output file doesn't exist
         if not os.path.exists(new_file_path) or page.get_modified_time() >= last_build_time:
             force_render = 1
@@ -169,7 +167,7 @@ class JinjaStaticRenderer():
         try:
             template_object = env.get_template(template)
         except:
-            template_object = False
+            return [new_file_path, 0, template]
 
         referenced_templates = self.get_referenced_templates(template)
         template_modified_time = self.get_template_mtime(template)
@@ -177,11 +175,10 @@ class JinjaStaticRenderer():
         if template_modified_time >= last_build_time:
             force_render = 1
 
-        if referenced_templates != False:
-            for t in referenced_templates:
-                time = self.get_template_mtime(t)
-                if time >= last_build_time:
-                    force_render = 1
+        for t in referenced_templates:
+            time = self.get_template_mtime(t)
+            if time >= last_build_time:
+                force_render = 1
 
         file_did_render = 0
 
